==> igniteui-webcomponents-core-4.2.5.tgz: package/esm5/lib/WebActiveStepChangedArgsDetailDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Description } from "./Description";
import { markType } from "./type";
/**
 * @hidden
 */
var WebActiveStepChangedArgsDetailDescription = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebActiveStepChangedArgsDetailDescription, _super);
    function WebActiveStepChangedArgsDetailDescription() {
        var _this = _super.call(this) || this;
        _this.g = 0;
        return _this;
    }
    WebActiveStepChangedArgsDetailDescription.prototype.get_type = function () {
        return "WebActiveStepChangedArgsDetail";
    };
    Object.defineProperty(WebActiveStepChangedArgsDetailDescription.prototype, "type", {
        get: function () {
            return this.get_type();
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(WebActiveStepChangedArgsDetailDescription.prototype, "index", {
        get: function () {
            return this.g;
        },
        set: function (a) {
            this.g = a;
            this.e("Index");
        },
        enumerable: true,
        configurable: true
    });
    WebActiveStepChangedArgsDetailDescription.$t = markType(WebActiveStepChangedArgsDetailDescription, 'WebActiveStepChangedArgsDetailDescription', Description.$);
    WebActiveStepChangedArgsDetailDescription.__marshalByValue = true;
    WebActiveStepChangedArgsDetailDescription.__marshalByValueAlias = "ActiveStepChangedArgsDetail";
    return WebActiveStepChangedArgsDetailDescription;
}(Description));
export { WebActiveStepChangedArgsDetailDescription };

==> igniteui-webcomponents-core-5.4.1.tgz: package/esm5/lib/WebActiveStepChangedArgsDetailDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Description } from "./Description";
import { markType } from "./type";
/**
 * @hidden
 */
var WebActiveStepChangedArgsDetailDescription = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebActiveStepChangedArgsDetailDescription, _super);
    function WebActiveStepChangedArgsDetailDescription() {
        var _this = _super.call(this) || this;
        _this.i = 0;
        return _this;
    }
    WebActiveStepChangedArgsDetailDescription.prototype.get_type = function () {
        return "WebActiveStepChangedArgsDetail";
    };
    Object.defineProperty(WebActiveStepChangedArgsDetailDescription.prototype, "type", {
        get: function () {
            return this.get_type();
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(WebActiveStepChangedArgsDetailDescription.prototype, "index", {
        get: function () {
            return this.i;
        },
        set: function (a) {
            this.i = a;
            this.g("Index");
        },
        enumerable: false,
        configurable: true
    });
    WebActiveStepChangedArgsDetailDescription.$t = markType(WebActiveStepChangedArgsDetailDescription, 'WebActiveStepChangedArgsDetailDescription', Description.$);
    WebActiveStepChangedArgsDetailDescription.__marshalByValue = true;
    WebActiveStepChangedArgsDetailDescription.__marshalByValueAlias = "ActiveStepChangedArgsDetail";
    return WebActiveStepChangedArgsDetailDescription;
}(Description));
export { WebActiveStepChangedArgsDetailDescription };
